@@ -59,8 +59,10 @@
   int set_mem(char [], char, int);
   int rm_crlf(char [], int);
   int swap_mem(char [], char, char);
+  int chmem(char [], int);
   int self_memcpy(char *, char *, int);
   int self_strncat(char *, char *, int);
+  int self_delim_get(char *, char *, char, int, int);
   int count_memcpy(char *, char *, int);
   char * count_memcpy2(char *, char *, int, int);
   int delim_count(char *, char, int, int *, int *);
@@ -91,6 +93,7 @@
   char * null_free(char *);
 
   /* --- socket --- */
+  int socket_reada(int, char *, int);
   int socket_reads(int, char * , int, int);
   int socket_sends(int, char *, int, char);
   int socket_send(int, char *, int);
@@ -130,6 +133,10 @@
   #include<pthread.h>
   int safe_pthread_mutex_lock(pthread_mutex_t *);
 
+  /* --- bit --- */
+  char * out_bit(unsigned int ina, char * bit, int bx);
+  unsigned long in_bit(char * bit, char bx);
+
 #endif
 
 
