@@ -275,6 +275,9 @@ print("<option value=UDP>UDPݡ");
 print("<option value=TCP>TCPݡ");
 print("<option value=URL>URL status");
 print("<option value=SMTP>SMTP status");
+print("<option value=FTP>FTP status");
+print("<option value=POP>POP status");
+print("<option value=SSH>SSH status");
 print("<option value=SNTP>NTPλ");
 print("<option value=HOST>DNS̾");
 echo "</select>";
