@@ -189,6 +189,9 @@ if(0 == strcmp($MONITOR, "PORT")){
    echo "<option value=URL>URL";
    echo "<option value=SSL>SSL";
    echo "<option value=SMTP>SMTP";
+   echo "<option value=FTP>FTP";
+   echo "<option value=POP>POP";
+   echo "<option value=SSH>SSH";
    echo "<option value=DHW>DHW";
    echo "<option value=SNTP>SNTP";
    echo "<option value=HOST>HOST";
