@@ -7,7 +7,8 @@
 
 #ifndef _JPRETURN_H_
   #define _JPRETURN_H_
-  
+
+ 
 #define SNMP_1 "OIDʸʤǤ͡  "
 #define SNMP_2 "ǥߥ'['οǤ  "
 #define SNMP_3 "§黻ҤǤ  "
@@ -69,6 +70,13 @@
 #define SMTP_4 "SMTP HELOФ֤äƤơɤ200Ǥ "
 #define SMTP_44 "SMTP ³֤äƤơɤ200Ǥ "
 
+#define STAT_1 "³νʳ֤äƤͤޤ "
+#define STAT_2 "쥯Ȥ۾ｪλƤޤ "
+#define STAT_3 "쥯ȤॢȤޤ³˻֤äƤޤ "
+#define STAT_4 "ǡ礭۾Ǥ "
+#define STAT_5 "ơޤ "
+#define STAT_6 "ơԤΤǤ "
+
 #define COM_1 "¹ԥޥɤॢȤޤ  "
 #define COM_2 "ޥɤ¹ԤǤޤǤ  "
 #define COM_3 "Ǥºݤͤ򲼤ƥ顼Ф뤫ǧƤ "
