@@ -48,16 +48,16 @@ if((gd.bf.c_name = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
 if((gd.ip.ip_addr = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
 if((gd.ip.ip2_addr = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
 
+/* dns_ip */
+if((gd.di.dns_name = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
+if((gd.di.dns_name2 = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
+
 /* mail_data */
 if((gd.smtp.ch_MailCc = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
 
 /* scan */
 if((gd.sd.swap = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ m_exit(1);}
 
-/* cron */
-// if((gd.cd.swap = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
-// if((gd.cd.scan_all = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
-
 
 if((fds = getdtablesize()) <= 0){
    fprintf(stderr,"p_open(): not get fd size.\n");
@@ -112,6 +112,9 @@ free(gd.bf.c_name);
 free(gd.ip.ip_addr);
 free(gd.ip.ip2_addr);
 
+/* dns_ip */
+free(gd.di.dns_name);
+
 /* mail_data */
 free(gd.smtp.ch_MailCc);
 
