@@ -15,6 +15,9 @@
 #include"jpreturn.h"
 #include<file_comp/file_comp.h>
 
+
+// #define MONITOR_BUG
+
 global_data_t gd;
 
 pthread_mutex_t exec_mutex;
@@ -28,6 +31,9 @@ int dstat, mode, i, fds, co;
 char mid_stat;
 extern char *optarg;
 
+if((gd.di.dns_name = (char *)calloc(IP_LEN, sizeof(char)))==NULL){ m_exit(1);}
+gd.di.dns_name = safe_memcpy(gd.di.dns_name, "127.0.0.1", BUF_MAX);
+
 mid_stat = 0;
 dstat = 0;
 mode = 0;
@@ -54,7 +60,7 @@ for(co = 0; co < COM_LEN; co++){
 
 
 // optionの処理
-while((i=getopt(argc,argv,"a:d:m:v"))!= EOF){
+while((i=getopt(argc,argv,"a:d:r:m:v"))!= EOF){
    switch(i){
       case 'm': if(0 == ch_int2(optarg)){
                    mode = strtol(optarg, (char **)NULL, 10);
@@ -67,8 +73,15 @@ while((i=getopt(argc,argv,"a:d:m:v"))!= EOF){
                    pd->sb.swap_2 = safe_memcpy(pd->sb.swap_2, "NOT_DATA", 1024);
                    }
               break;
+      case 'r': if(optarg != NULL){
+                   gd.di.dns_name = safe_memcpy(gd.di.dns_name, optarg, BUF_MAX);
+                   }
+                else{
+                   gd.di.dns_name = safe_memcpy(gd.di.dns_name, "127.0.0.1", BUF_MAX);
+                   }
+              break;
 
-      default : printf("scan_block_test-%s $scan_bloc_test -d <monitor_data> -m <0-1>\n",VERSION);
+      default : printf("scan_block_test-%s $scan_bloc_test -d <monitor_data> -m <0-1> -r <dns ip address>\n",VERSION);
              for(co = 0; co < COM_LEN; co++){
                 free(pids[co]);
                 }
@@ -166,35 +179,35 @@ if('#' != pd->sb.swap_2[0]){
 
             if(0 == self_memcmp(pd->sb.ch_tool, "PORT")){
                #ifdef MONITOR_BUG
-               printf("MONITOR: %s: %s: %s: %s:\n",
+               fprintf(stderr,"MONITOR 1: %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
                #endif 
                scan_port(&pd->sb);
                }
             else if(0 == self_memcmp(pd->sb.ch_tool, "COMAND")){
                #ifdef MONITOR_BUG
-               printf("MONITOR: %s: %s: %s: %s:\n",
+               fprintf(stderr,"MONITOR 2: %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_com, pd->sb.ch_free1, pd->sb.ch_free4);
                #endif 
                scan_comand(pd);
                }
             else if(0 == self_memcmp(pd->sb.ch_tool, "SNMP")){
                #ifdef MONITOR_BUG
-               printf("MONITOR: %s: %s: %s: %s:\n",
+               fprintf(stderr,"MONITOR 3: %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
                #endif 
                scan_snmp(&pd->sb);
                }
-            else if(0 == self_memcmp(pd->sb.ch_tool, "SET")){
+/*          else if(0 == self_memcmp(pd->sb.ch_tool, "SET")){
                #ifdef MONITOR_BUG
-               printf("MONITOR: %s: %s: %s: %s:\n",
+               fprintf(stderr,"MONITOR 4: %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
                #endif 
                pd->sb.check_stat = 2;
-               }
+               } */
             else{
                #ifdef MONITOR_BUG
-               printf("scan_block(): 存在しない監視属性が設定されています %s: %s: %s: %s:\n",
+               fprintf(stderr,"MONITOR 5: scan_block(): 存在しない監視属性が設定されています %s: %s: %s: %s:\n",
                  pd->sb.ch_tool, pd->sb.ch_prot, pd->sb.ch_free1, pd->sb.ch_free4);
                #endif 
 
@@ -206,14 +219,14 @@ if('#' != pd->sb.swap_2[0]){
                }
 
 
-            // SET 行の場合の処理になります
+/*            // SET 行の場合の処理になります
             if(pd->sb.check_stat == 2 ){
                printf("OK : SET LINE : %s\n", pd->sb.swap_2);
-               }  // SET の処理最後  
+               }  // SET の処理最後   */
 
 
             // ERR が観測された場合の処理。
-            else if(pd->sb.check_stat == 1){
+            if(pd->sb.check_stat == 1){
                if(mode == 0){
                   swap_mem(pd->sb.ch_info, ';', ' ');
                   printf("ERR: %s\n", pd->sb.ch_info);
@@ -275,6 +288,8 @@ for(co = 0; co < COM_LEN; co++){
    }
 scan_malloc_free(pd);
 free(pd);
+free(gd.di.dns_name);
+
 
 return 0;
 }
