@@ -14,12 +14,15 @@
 #include<sys/stat.h>
 #include<errno.h>
 
+#include"sitar.h"
 #include"sitar_scan.h"
 #include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
+// #define DHW_BUG
 
+extern global_data_t gd;
 
 
 /* 0-> dhw exc command line 1-> port No' 2-> Ipsddr 3-> return data,, return status code 0=open or=close
@@ -30,7 +33,7 @@ int scan_smtp_connect(int, char *, char *, int);
 /*----------------- SCAN DHW CONNECT --------------------*/
 char * scan_dhw_connect(char * comand, int port, char * url_dom, char * backdata, int timeout, int * pst)
 {
-int sk, re, ret, retval, arglen, dcount;
+int sk, re, ret, retval, arglen, dcount, resolv_ret;
 char ipa[IP_LEN];
 char * ip_addr = ipa;
 unsigned long resoip;
@@ -68,7 +71,19 @@ my_addr.sin_family = AF_INET;
 my_addr.sin_port = htons(port);
 
 resoip = 0;
-backdata = resolvename(backdata, url_dom, timeout, &resoip);
+resolv_ret = 0;
+
+if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
+   backdata = resolvename_th(backdata, url_dom, timeout, &resoip);
+   }
+else{
+   backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   if(resolv_ret < 0){
+      backdata = resolvename_sk(backdata, url_dom, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret);
+      fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> %s\n", url_dom, backdata);
+      }
+   }
+
 my_addr.sin_addr.s_addr = resoip;
 
 if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
@@ -136,6 +151,8 @@ if(errno == EINPROGRESS){
          }
       // 時間内に接続出来たのでLoopOUTします。
       else{
+         // 非同期通信から同期通信に
+         fcntl(sk, F_SETFL, 0);
          backdata=safe_sprintf(backdata,BUF_MAX,
           "URL=%s Port=%d %s", url_dom, port, SOCK_3);
          #ifdef DHW_BUG
@@ -146,8 +163,6 @@ if(errno == EINPROGRESS){
       }
 
 
-   // 非同期通信から同期通信に
-   fcntl(sk, F_SETFL, 0);
 
    // select を省いたGOTO
    notselect :;
@@ -239,11 +254,14 @@ if(errno == EINPROGRESS){
 
             // select 正常
             else{
-               dcount = recv(sk, recvdata, BUF_LEN, 0);
+//             dcount = recv(sk, recvdata, BUF_LEN, 0);
+               dcount = socket_reada(sk, recvdata, BUF_LEN);
                #ifdef DHW_BUG
                printf("DHW: scan_dhw_connect(12): recv-- %s --\n", recvdata);
                #endif
 
+// printf("dcount=%d  tcount=%d\n", dcount, 1 + (mem_tcount(recvdata, '\n')));
+
                // 受信量がゼロ、エラーではない場合
                if(dcount < 1){
                   backdata = safe_sprintf(backdata,BUF_MAX,
@@ -254,12 +272,28 @@ if(errno == EINPROGRESS){
                   #endif
                   }
 
+
                // 何らかのエラーを取得した場合
                else{
-               ret = -1;
-                  #ifdef DHW_BUG
-                  printf("DHW: scan_dhw_connect(14): <%d><2> %s\n", ret, backdata);
-                  #endif
+                  if(0 == memcmp(recvdata, "###DHWINFO ", 11)){                  
+                     if(dcount == 1 + (mem_tcount(recvdata, '\n'))){
+                        ret = 0;
+                        }
+                     else{
+
+
+                        ret = -1;
+                        #ifdef DHW_BUG
+                        printf("DHW: scan_dhw_connect(14): <%d><2> %s\n", ret, backdata);
+                        #endif
+                        }
+                     }
+                  else{
+                     ret = -1;
+                     #ifdef DHW_BUG
+                     printf("DHW: scan_dhw_connect(14-2): <%d><2> %s\n", ret, backdata);
+                     #endif
+                     }
                   }
 
                if(ret == -1){
@@ -270,6 +304,7 @@ if(errno == EINPROGRESS){
                #ifdef DHW_BUG
                printf("DHW: scan_dhw_connect(15): %d <2> %s\n", ret, backdata);
                #endif
+
                // 非同期通信から同期通信に戻す
                fcntl(sk, F_SETFL, 0);
                close(sk);
