@@ -13,11 +13,13 @@
 #include<sys/stat.h> 
 #include<sys/un.h>
 
+#include"sitar.h"
 #include"sitar_scan.h"
 #include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
+extern global_data_t gd;
 
 
 /* ------------ TVSUB --------------- */
@@ -82,6 +84,8 @@ return 0;
 /*----------------- SCAN ICMP --------------------*/
 char * scan_icmp(char * url_data, char * backdata, int timeout, int * stat, int coe)
 {
+int resolv_ret;
+
 int send_sk, hlen, i;
 float rtt;
 unsigned long resoip;
@@ -110,6 +114,7 @@ urldompass_port(url_data, ip_addr, url_pass, strlen(url_data));
 // 初期化
 rtt = 0.0;
 i = 0;
+resolv_ret = 0;
 
 memset((char *)&send_addr, 0, sizeof(struct sockaddr_in));
 memset(ipa2, 0x00, IP_LEN);
@@ -120,7 +125,20 @@ send_addr.sin_family = AF_INET;
 
 // 名前解決
 resoip = 0;
-backdata = resolvename(backdata, ip_addr, timeout, &resoip);
+// backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
+// backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, &resolv_ret);
+
+if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
+   backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
+   }
+else{
+   backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   if(resolv_ret < 0){
+      backdata = resolvename_sk(backdata, ip_addr, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret);
+      fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> %s\n", ip_addr, backdata);
+      }
+   }
+
 send_addr.sin_addr.s_addr = resoip;
 
 if(0 == (int)send_addr.sin_addr.s_addr || resoip == (int)NULL){
