@@ -13,6 +13,7 @@
 #include"jpreturn.h"
 
 
+
 /* ------ SCAN PORT --------- */
 int scan_port(struct scan_buf *pd)
 {
@@ -93,6 +94,27 @@ else if((self_memcmp(pd->ch_prot,"SMTP")) == 0){
       }
    }
 
+else if((self_memcmp(pd->ch_prot,"FTP")) == 0){
+   pd->ch_info = scan_stat_connect(pd->port, pd->ch_host, pd->ch_info, "220", 3, pd->timeout, &ret);
+   if(0 == (int)strlen(pd->ch_info)){
+      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+
+else if((self_memcmp(pd->ch_prot,"POP")) == 0){
+   pd->ch_info = scan_stat_connect(pd->port, pd->ch_host, pd->ch_info, "+OK", 3, pd->timeout, &ret);
+   if(0 == (int)strlen(pd->ch_info)){
+      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+
+else if((self_memcmp(pd->ch_prot,"SSH")) == 0){
+   pd->ch_info = scan_stat_connect(pd->port, pd->ch_host, pd->ch_info, "SSH", 3, pd->timeout, &ret);
+   if(0 == (int)strlen(pd->ch_info)){
+      pd->ch_info=safe_memcpy(pd->ch_info,"Information is a no bur error.\n",BUF_MAX);
+      }
+   }
+
 else if((self_memcmp(pd->ch_prot,"DHW")) == 0){
    pd->ch_info = scan_dhw_connect(pd->ch_com, pd->port, pd->ch_host, pd->ch_info, pd->timeout,&ret);
    if(0 == (int)strlen(pd->ch_info)){
