@@ -14,13 +14,17 @@
 #include<sys/stat.h>
 #include<errno.h>
 
+#include"sitar.h"
 #include"sitar_scan.h"
 #include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
+// #define SMTP_BUG
 
 
+extern global_data_t gd;
+
 /* 1-> port No' 2-> Ipsddr 3-> return data,, return status code 0=open or=close
 int scan_smtp_connect(int, char *, char *, int);
 */
@@ -71,7 +75,7 @@ return(ret);
 /*----------------- SCAN TCP CONNECT --------------------*/
 char * scan_smtp_connect(int port, char * url_dom, char * backdata, int timeout, int * pst)
 {
-int sk, re, ret, retval, dcount, arglen;
+int sk, re, ret, retval, dcount, arglen, resolv_ret;
 unsigned long resoip;
 char ipa[IP_LEN];
 char * ip_addr = ipa;
@@ -92,6 +96,7 @@ memset(senddata, 0x00, BUF_LEN);
 ret = -1;
 errno = 0;
 dcount = 0;
+resolv_ret = 0;
 arglen = sizeof(int);
 
 
@@ -107,7 +112,16 @@ my_addr.sin_family = AF_INET;
 my_addr.sin_port = htons(port);
 
 resoip = 0;
-backdata = resolvename(backdata, url_dom, timeout, &resoip);
+// backdata = resolvename_th(backdata, url_dom, timeout, &resoip);
+// backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, &resolv_ret);
+
+if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
+   backdata = resolvename_th(backdata, url_dom, timeout, &resoip);
+   }
+else{
+   backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   }
+
 my_addr.sin_addr.s_addr = resoip;
 
 if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
@@ -176,6 +190,8 @@ if(errno == EINPROGRESS){
          }
       // 時間内に接続出来たのLoopOut
       else {
+         // 非同期通信から同期通信に
+         fcntl(sk, F_SETFL, 0);
          #ifdef SMTP_BUG
          printf("SMTP: scan_smtp_connect(4): select time succes BREAK- %d -\n", retval);
          #endif
@@ -185,8 +201,6 @@ if(errno == EINPROGRESS){
          }
       }
 
-   // 非同期通信から同期通信に
-   fcntl(sk, F_SETFL, 0);
 
    // select を省いたGOTO
    notselect :;
@@ -258,7 +272,8 @@ if(errno == EINPROGRESS){
             else{
 
                // fdに変化があったので読んでみたりするテスト
-               dcount = recv(sk, recvdata, BUF_LEN, 0);
+//             dcount = recv(sk, recvdata, BUF_LEN, 0);
+               dcount = socket_reada(sk, recvdata, BUF_LEN);
 
                #ifdef SMTP_BUG
                printf("SMTP: scan_smtp_connect(9): recv-- %s --\n", recvdata);
@@ -269,9 +284,18 @@ if(errno == EINPROGRESS){
                    "URL=%s Port=%d %s"
                    , url_dom, port, SMTP_22);
                   ret = -1;
+                  // 非同期通信から同期通信に
+                  fcntl(sk, F_SETFL, 0);
+                  close(sk);
+                  * pst = -1;
+                  return backdata;
                   }
                // 受信量は正常
                else{
+
+
+// printf("1 dcount=<%d>  SEND=<%s> \n RECV=<%s>\n", dcount, senddata, recvdata);
+
                   ch_char(recvdata, senddata);
                   swap_mem(senddata, '\n', ' ');
                   swap_mem(senddata, ',', ' ');
@@ -311,6 +335,8 @@ if(errno == EINPROGRESS){
 
 
 
+         memset(recvdata, 0x00, BUF_LEN);
+         memset(senddata, 0x00, BUF_LEN);
 
 
          //  SMTPから返事があったので、HELOを送ってステータスをまちます
@@ -360,7 +386,10 @@ if(errno == EINPROGRESS){
                return backdata;
                }
             else{
-               dcount = recv(sk, recvdata, BUF_LEN, 0);
+
+//             dcount = recv(sk, recvdata, 256, 0);
+               dcount = socket_reada(sk, recvdata, BUF_LEN);
+
                #ifdef SMTP_BUG
                printf("SMTP: scan_smtp_connect(15): recv-- %s --\n", recvdata);
                #endif
@@ -373,6 +402,11 @@ if(errno == EINPROGRESS){
                   }
                // 受信量は正常
                else{
+
+// printf("2 dcount=<%d> SEND=<%s> \n RECV=<%s>\n", dcount, senddata, recvdata);
+
+                  memset(senddata, 0x00, BUF_LEN);
+
                   ch_char(recvdata, senddata);
                   swap_mem(senddata, '\n', ' ');
                   swap_mem(senddata, ',', ' ');
