@@ -19,12 +19,13 @@
 #include<sys/time.h>
 #include<errno.h>
 
+#include"sitar.h"
 #include"sitar_scan.h"
 #include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
-
+extern global_data_t gd;
 
 
 #define JAN_1970   2208988800.0        /* 1970 - 1900 in seconds */
@@ -102,7 +103,7 @@ struct req_pkt {
 /*----------------- SCAN SNTP CONNECT --------------------*/
 char * scan_sntp_connect(int port, char ip_addr[], char * backdata, int timeout, int * ret)
 {
-int send_sk, con, retval;
+int send_sk, con, retval, resolv_ret;
 struct sockaddr_in server;
 struct sockaddr_in client;
 struct timeval tv;
@@ -118,6 +119,7 @@ fd_set select_fd;
 con = 0;
 * ret = 0;
 retval = 0;
+resolv_ret = 0;
 backdata[0] = (char)0x00;
 
 
@@ -140,9 +142,21 @@ if(bind(send_sk, (void *)&client, sizeof(client)) < 0){
    }
 
 server.sin_family = AF_INET;
-// server.sin_addr.s_addr = resolvename(ip_addr,timeout);
 resoip = 0;
-backdata = resolvename(backdata, ip_addr, timeout, &resoip);
+//backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
+//backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, &resolv_ret);
+
+if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
+   backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
+   }
+else{
+   backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   if(resolv_ret < 0){
+      backdata = resolvename_sk(backdata, ip_addr, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret);
+      fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> %s\n", ip_addr, backdata);
+      }
+   }
+
 server.sin_addr.s_addr = resoip;
 
 if(0 == (int)server.sin_addr.s_addr || resoip == (int)NULL){
