@@ -11,11 +11,13 @@
 #include<sys/stat.h>
 #include<errno.h>
 
+#include"sitar.h"
 #include"sitar_scan.h"
 #include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
+extern global_data_t gd;
 
 /* 1-> port No' 2-> Ipsddr 3-> return data,, return status code 0=open or=close
 int scan_tcp_connect(int, char *, char *, int);
@@ -33,7 +35,7 @@ char pas[BUF_URL];
 char * url_pass = pas;
 char buff[256];
 
-int sk, re, retval, arglen, port2;
+int sk, re, retval, arglen, port2, resolv_ret;
 unsigned long resoip;
 struct sockaddr_in my_addr;
 fd_set rfds;
@@ -42,6 +44,7 @@ struct timeval tv;
 arglen = sizeof(int);
 
 errno = 0;
+resolv_ret = 0;
 
 memset(ip_addr, 0x00, BUF_URL);
 memset(url_pass, 0x00, BUF_URL);
@@ -67,7 +70,21 @@ my_addr.sin_family = AF_INET;
 my_addr.sin_port = htons(port);
 
 resoip = 0;
-backdata = resolvename(backdata, ip_addr, timeout, &resoip);
+// backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
+// backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, &resolv_ret);
+
+if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
+   backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
+   }
+else{
+   backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   if(resolv_ret < 0){
+      backdata = resolvename_sk(backdata, ip_addr, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret);
+      fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> %s\n", ip_addr, backdata);
+      }
+   }
+
+
 my_addr.sin_addr.s_addr = resoip;
 
 if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
