@@ -10,12 +10,13 @@
 #include<sys/stat.h>
 #include<arpa/inet.h>
 
+#include"sitar.h"
 #include"sitar_scan.h"
 #include"sitar_com.h"
 #include<almemsys/almemsys.h>
 #include"jpreturn.h"
 
-
+extern global_data_t gd;
 
 /* 1-> port No' 2-> Ipsddr 3-> return data,, return status code 0=open or=close
 int scan_udp_connect(int, char *, char *, int);
@@ -35,7 +36,7 @@ char * ip_addr = ip;
 char pas[BUF_URL];
 char * url_pass = pas;
 
-int send_sk, recv_sk, select_stat, port2;
+int send_sk, recv_sk, select_stat, port2, resolv_ret;
 unsigned long resoip;
 struct icmp *icmp;
 struct sockaddr_in send_addr;
@@ -56,7 +57,23 @@ if(port2 > 0){
 
 
 resoip = 0;
-backdata = resolvename(backdata, ip_addr, timeout, &resoip);
+resolv_ret = 0;
+
+// backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
+// backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, &resolv_ret);
+
+if(0 == self_memcmp(gd.di.dns_name, "RESOLV")){
+   backdata = resolvename_th(backdata, ip_addr, timeout, &resoip);
+   }
+else{
+   backdata = resolvename_sk(backdata, ip_addr, timeout, &resoip, gd.di.dns_name, &resolv_ret);
+   if(resolv_ret < 0){
+      backdata = resolvename_sk(backdata, ip_addr, DEFAULT_TIMEOUT, &resoip, gd.di.dns_name2, &resolv_ret);
+      fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> %s\n", ip_addr, backdata);
+      }
+   }
+
+
 send_addr.sin_addr.s_addr = resoip;
 
 if(0 == (int)send_addr.sin_addr.s_addr || resoip == (int)NULL){
