@@ -35,7 +35,6 @@
 
 // #define SSL_BUG
 
-// char * scan_ssl_connect(int port, char * url_data, char * backdata, int timeout, long int cert_lim, int * pst)
 int main(int argc, char * argv[])
 {
 int sk, re, stat, ret, retval, dcount, arglen, sslerr, i;
@@ -65,6 +64,8 @@ int port;
 int timeout;
 long int cert_lim;
 char * url_data; 
+char * dns_data; 
+int resolv_ret;
 
 time_t B_time, A_time, N_time, Na_time;
 B_time =0; A_time =0; N_time =0;
@@ -87,9 +88,11 @@ sslerr = 0;
 port = 0;
 timeout = 0;
 cert_lim = 0;
+resolv_ret = 0;
 
 if((senddata = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ exit(1);}
 if((url_data = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ exit(1);}
+if((dns_data = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ exit(1);}
 if((backdata = (char *)calloc(BUF_LEN, sizeof(char)))==NULL){ exit(1);}
 
 memset(recvdata, 0x00, 256);
@@ -98,8 +101,11 @@ memset(ip_addr, 0x00, IP_LEN);
 memset(url_dom, 0x00, BUF_URL);
 memset(url_pass, 0x00, BUF_URL);
 
+// defaultのDNSを設定
+dns_data = safe_memcpy(dns_data, "127.0.0.1", 1024);
+
 // optionの処理
-while((i=getopt(argc,argv,"a:p:t:c:u:v:z"))!= EOF){
+while((i=getopt(argc,argv,"a:p:t:c:u:v:d:z"))!= EOF){
    switch(i){
       case 'p': if(0 == ch_int2(optarg)){
                    port = strtol(optarg, (char **)NULL, 10);
@@ -120,10 +126,18 @@ while((i=getopt(argc,argv,"a:p:t:c:u:v:z"))!= EOF){
                    url_data = safe_memcpy(url_data, "http:///", 1024);
                    }
               break;
+      case 'd': if(optarg != NULL){
+                   dns_data = safe_memcpy(dns_data, optarg, 1024);
+                   }
+                else{
+                   dns_data = safe_memcpy(dns_data, "127.0.0.1", 1024);
+                   }
+              break;
 
       default : printf("scanssl-%s $scanssl -p <port> -t <timout> -c <cert time limmit> -u <https://URL>\n",VERSION);
               free(senddata);
               free(url_data);
+              free(dns_data);
               free(backdata);
               exit(1);
               break;
@@ -137,36 +151,55 @@ if(stat > 0){
 
 
 #ifdef SSL_BUG
-printf("SSL_BUG: scan_ssl_connect():\n url_data=<%s>\n url_dom=<%s>\n url_pass=<%s>\n url_port=<%d>\n", url_data, url_dom, url_pass, port);
+printf("SSL_BUG: scanssl():\n url_data=<%s>\n url_dom=<%s>\n url_pass=<%s>\n url_port=<%d>\n", url_data, url_dom, url_pass, port);
 #endif
 
+// ソケット生成
 if((sk = socket(AF_INET, SOCK_STREAM, 0))==-1){
+   // ソケットつくれないので離脱
    printf("URL=%s Port=%d tcp %s\n", url_data, port, SOCK_1);
    #ifdef SSL_BUG
-   printf("SSL_BUG: scan_ssl_connect(1): NOT CLEATE SOCKETS %s\n", backdata);
+   printf("SSL_BUG: scanssl(1): NOT CLEATE SOCKETS %s\n", backdata);
    #endif
    free(senddata);
    free(url_data);
+   free(dns_data);
    free(backdata);
-   // ソケットつくれないので離脱
    exit(1);
    }
 
 my_addr.sin_family = AF_INET;
 my_addr.sin_port = htons(port);
 
-backdata = out_resolvename(backdata, url_dom, timeout, &resoip);
+// backdata = out_resolvename(backdata, url_dom, timeout, &resoip);
+// my_addr.sin_addr.s_addr = resoip;
+
+backdata = resolvename_sk(backdata, url_dom, timeout, &resoip, dns_data, &resolv_ret);
+if(resolv_ret < 0){
+   printf("DNS=<%s> %s %s\n", dns_data, SOCK_2, url_dom);
+   #ifdef SSL_BUG
+   fprintf(stderr,"RESOLV ERR: DNS name resolution failure <%s> <%s> <%s>\n", url_dom, backdata, dns_data);
+   #endif
+   free(senddata);
+   free(url_data);
+   free(dns_data);
+   free(backdata);
+   exit(1);
+   }
+
 my_addr.sin_addr.s_addr = resoip;
 
+
 if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
 // printf("%s %s %d\n", SOCK_2, url_dom, (int)my_addr.sin_addr.s_addr);
    printf("%s %s\n", SOCK_2, url_dom);
    #ifdef SSL_BUG
-   printf("SSL_BUG: scan_ssl_connect(2):  NOT RESOLV NAME %s\n", backdata);
+   printf("SSL_BUG: scanssl(2):  NOT RESOLV NAME %s\n", backdata);
    #endif
    close(sk);
    free(senddata);
    free(url_data);
+   free(dns_data);
    free(backdata);
    // アドレスがへんだから離脱
    exit(1);
@@ -176,7 +209,7 @@ if(0 == (int)my_addr.sin_addr.s_addr || resoip == (int)NULL){
 ip_addr = inet_ntop(AF_INET, &my_addr.sin_addr, buff, sizeof(buff));
 
 #ifdef SSL_BUG
-printf("SSL_BUG: scan_ssl_connect(3): %s\n", ip_addr);
+printf("SSL_BUG: scanssl(3): %s\n", ip_addr);
 #endif
 
 // 非同期通信の開始 TCP ポートにコネ串ょん
@@ -205,13 +238,14 @@ if(errno == EINPROGRESS){
       if(retval < 0){
          printf("URL=%s Port=%d %s %s\n", url_data, port, SOCK_15, SOCK_5);
          #ifdef SSL_BUG
-         printf("SSL_BUG: scan_ssl_connect(4): select error BREAK- %d - %s\n", retval, backdata);
+         printf("SSL_BUG: scanssl(4): select error BREAK- %d - %s\n", retval, backdata);
          #endif
          // 非同期通信から同期通信に
          fcntl(sk, F_SETFL, 0);
          close(sk);
          free(senddata);
          free(url_data);
+         free(dns_data);
          free(backdata);
          // select へんなんで離脱
          exit(1);
@@ -221,13 +255,14 @@ if(errno == EINPROGRESS){
       else if(retval == 0){
          printf("URL=%s Port=%d %s %s\n", url_data, port, SOCK_16, SOCK_5);
          #ifdef SSL_BUG
-         printf("SSL_BUG: scan_ssl_connect(5): select time out BREAK- %d - %s\n", retval, backdata);
+         printf("SSL_BUG: scanssl(5): select time out BREAK- %d - %s\n", retval, backdata);
          #endif
          // 非同期通信から同期通信に
          fcntl(sk, F_SETFL, 0);
          close(sk);
          free(senddata);
          free(url_data);
+         free(dns_data);
          free(backdata);
          // select timeout なので離脱
          exit(1);
@@ -235,7 +270,7 @@ if(errno == EINPROGRESS){
       // 時間内に接続出来たのでLoopOUTします
       else{
          #ifdef SSL_BUG
-         printf("SSL_BUG: scan_ssl_connect(6): select time succes BREAK-%d- %s\n", retval, backdata);
+         printf("SSL_BUG: scanssl(6): select time succes BREAK-%d- %s\n", retval, backdata);
          #endif
          break;
          }
@@ -251,11 +286,12 @@ if(errno == EINPROGRESS){
    if(getsockopt(sk, SOL_SOCKET, SO_ERROR, (void *)&retval, (void *)&arglen) < 0){
       printf("URL=%s Port=%d %s\n", url_data, port, SOCK_13);
       #ifdef SSL_BUG
-      printf("SSL_BUG: scan_ssl_connect(): getsockopt(7) Errors!\n");
+      printf("SSL_BUG: scanssl(): getsockopt(7) Errors!\n");
       #endif
       close(sk);
       free(senddata);
       free(url_data);
+      free(dns_data);
       free(backdata);
       // getsockopt異常、離脱
       exit(1);
@@ -265,11 +301,12 @@ if(errno == EINPROGRESS){
       if(retval){
          printf("URL=%s Port=%d %s: TCP %s\n", url_data, port, (retval != 0) ? strerror(retval): "0", SOCK_5);
          #ifdef SSL_BUG
-         printf("SSL_BUG: scan_ssl_connect(8): 1 SO_ERROR %d %s\n", retval, backdata);
+         printf("SSL_BUG: scanssl(8): 1 SO_ERROR %d %s\n", retval, backdata);
          #endif
          close(sk);
          free(senddata);
          free(url_data);
+         free(dns_data);
          free(backdata);
          // エラーがあるの
          exit(1);
@@ -285,7 +322,7 @@ if(errno == EINPROGRESS){
          if( ctx == NULL ){
             // ERR_print_errors_fp(stderr);
             #ifdef SSL_BUG
-            printf("SSL_BUG: scan_ssl_connect(): SSL_CTX_new() failed:\n");
+            printf("SSL_BUG: scanssl(): SSL_CTX_new() failed:\n");
             #endif
             printf("URL=%s Port=%d : %s\n", url_data, port, "ssl_ctx object cannot be generated.");
             SSL_CTX_free(ctx);
@@ -293,6 +330,7 @@ if(errno == EINPROGRESS){
             close(sk);
             free(senddata);
             free(url_data);
+            free(dns_data);
             free(backdata);
             // SSLライブラリが初期化できぬ
             exit(1);
@@ -305,7 +343,7 @@ if(errno == EINPROGRESS){
             sslerr = SSL_get_error(ssl, ret);
             ERR_error_string(sslerr, swapdata);
             #ifdef SSL_BUG
-            printf("SSL_BUG: scan_ssl_connect(): SSL_new() failed: %s\n", swapdata);
+            printf("SSL_BUG: scanssl(): SSL_new() failed: %s\n", swapdata);
             #endif
             printf("URL=%s Port=%d %s : %s\n", url_data, port, swapdata, "structure cannot be initialized.");
             SSL_free(ssl);
@@ -314,6 +352,7 @@ if(errno == EINPROGRESS){
             close(sk);
             free(senddata);
             free(url_data);
+            free(dns_data);
             free(backdata);
             // SSL構造体が初期化できぬ
             exit(1);
@@ -326,7 +365,7 @@ if(errno == EINPROGRESS){
             sslerr = SSL_get_error(ssl, ret);
             ERR_error_string(sslerr, swapdata);
             #ifdef SSL_BUG
-            printf("SSL_BUG: scan_ssl_connect(): SSL_set_fd() failed: %s\n", swapdata);
+            printf("SSL_BUG: scanssl(): SSL_set_fd() failed: %s\n", swapdata);
             #endif
             printf("URL=%s Port=%d %s : %s\n", url_data, port, swapdata, "descriptor cannot be made.");
             SSL_free(ssl);
@@ -335,6 +374,7 @@ if(errno == EINPROGRESS){
             close(sk);
             free(senddata);
             free(url_data);
+            free(dns_data);
             free(backdata);
             // SSLディスクリプタのすり替えがしっぱい
             exit(1);
@@ -355,7 +395,7 @@ if(errno == EINPROGRESS){
             sslerr = SSL_get_error(ssl, ret);
             ERR_error_string(sslerr, swapdata);
             #ifdef SSL_BUG
-            printf("SSL_BUG: scan_ssl_connect(): SSL_connect() failed: %d %s\n",ret, swapdata);
+            printf("SSL_BUG: scanssl(): SSL_connect() failed: %d %s\n",ret, swapdata);
             #endif
             printf("URL=%s Port=%d %s : %s\n", url_data, port, swapdata, "SSL cannot be used.\n");
             SSL_shutdown(ssl); 
@@ -365,6 +405,7 @@ if(errno == EINPROGRESS){
             close(sk);
             free(senddata);
             free(url_data);
+            free(dns_data);
             free(backdata);
             // SSLでのコネクションが確立できぬ
             exit(1);
@@ -383,7 +424,7 @@ if(errno == EINPROGRESS){
             SSL_CIPHER_get_name(cipher),
             SSL_CIPHER_get_bits(cipher, NULL));
 
-         printf("SSL: scan_ssl_connect(cipher): %s\n", backdata);
+         printf("SSL: scanssl(cipher): %s\n", backdata);
          #endif
 */
 
@@ -400,7 +441,7 @@ if(errno == EINPROGRESS){
             "It is outside the expiration date."); 
 
          #ifdef SSL_BUG
-         printf("SSL_BUG: scan_ssl_connect(cert): %s\n", backdata);
+         printf("SSL_BUG: scanssl(cert): %s\n", backdata);
          #endif
 */
 
@@ -440,7 +481,7 @@ if(errno == EINPROGRESS){
                      utime_getr(Na_time, 'd'),
                      X509_1); 
                   #ifdef SSL_BUG
-                  printf("SSL_BUG: scan_ssl_connect(x509): %s\n", backdata);
+                  printf("SSL_BUG: scanssl(x509): %s\n", backdata);
                   #endif
 
                   X509_free(cert);
@@ -451,6 +492,7 @@ if(errno == EINPROGRESS){
                   ERR_free_strings();
                   free(senddata);
                   free(url_data);
+                  free(dns_data);
                   free(backdata);
                   // 有効期限に達してないのでエラーはやすぎんだよ。
                   exit(1);
@@ -476,7 +518,7 @@ if(errno == EINPROGRESS){
                      utime_getr(Na_time, 'd'),
                      X509_2); 
                   #ifdef SSL_BUG
-                  printf("SSL_BUG: scan_ssl_connect(x509): %s\n", backdata);
+                  printf("SSL_BUG: scanssl(x509): %s\n", backdata);
                   #endif
                   X509_free(cert);
                   SSL_shutdown(ssl); 
@@ -486,6 +528,7 @@ if(errno == EINPROGRESS){
                   ERR_free_strings();
                   free(senddata);
                   free(url_data);
+                  free(dns_data);
                   free(backdata);
                   // そろそろ注意だといってみる
                   exit(1);
@@ -510,7 +553,7 @@ if(errno == EINPROGRESS){
                      utime_getr(Na_time, 'd'),
                      X509_3); 
                   #ifdef SSL_BUG
-                  printf("SSL_BUG: scan_ssl_connect(x509): %s\n", backdata);
+                  printf("SSL_BUG: scanssl(x509): %s\n", backdata);
                   #endif
 
                   X509_free(cert);
@@ -521,6 +564,7 @@ if(errno == EINPROGRESS){
                   ERR_free_strings();
                   free(senddata);
                   free(url_data);
+                  free(dns_data);
                   free(backdata);
                   // のこり3日で離脱
                   exit(1);
@@ -545,7 +589,7 @@ if(errno == EINPROGRESS){
                      utime_getr(Na_time, 'd'),
                      X509_4); 
                   #ifdef SSL_BUG
-                  printf("SSL_BUG: scan_ssl_connect(x509): %s\n", backdata);
+                  printf("SSL_BUG: scanssl(x509): %s\n", backdata);
                   #endif
 
                   X509_free(cert);
@@ -556,18 +600,19 @@ if(errno == EINPROGRESS){
                   ERR_free_strings();
                   free(senddata);
                   free(url_data);
+                  free(dns_data);
                   free(backdata);
                   // すぎちゃったの
                   exit(1);
                   }
                else {
                   #ifdef SSL_BUG
-                  printf("SSL_BUG: scan_ssl_connect(x509): %s\n", backdata);
+                  printf("SSL_BUG: scanssl(x509): %s\n", backdata);
                   #endif
                   }
                }
             else{                                                  // 閾値が0の場合はCERTの期限監視は行わない
-//             fprintf(stderr,"SSL_BUG: scan_ssl_connect(): 鍵の有効期限を過ぎていますが、閾値が0なので無視しています \n");
+//             fprintf(stderr,"SSL_BUG: scanssl(): 鍵の有効期限を過ぎていますが、閾値が0なので無視しています \n");
                }
 
 
@@ -577,7 +622,7 @@ if(errno == EINPROGRESS){
             if(sslerr != 0 && sslerr != 20){
                printf("509_verify NG: id=%d, data=%s\n", sslerr, backdata);
                #ifdef SSL_BUG
-               printf("SSL_BUG: scan_ssl_connect(x509_verify) NG: id=%d, data=%s\n", sslerr, backdata);
+               printf("SSL_BUG: scanssl(x509_verify) NG: id=%d, data=%s\n", sslerr, backdata);
                #endif
 
                X509_free(cert);
@@ -588,20 +633,21 @@ if(errno == EINPROGRESS){
                ERR_free_strings();
                free(senddata);
                free(url_data);
+               free(dns_data);
                free(backdata);
                // 証明書になにやら問題があるね。
                exit(1);
                }
             else{
                #ifdef SSL_BUG
-               printf("SSL_BUG: scan_ssl_connect(x509_verify) OK: id=%d, data=%s\n", sslerr, backdata);
+               printf("SSL_BUG: scanssl(x509_verify) OK: id=%d, data=%s\n", sslerr, backdata);
                #endif
                }
             }
          else {
             printf("Server does not have certificate.\n");
             #ifdef SSL_BUG
-            printf("SSL_BUG: scan_ssl_connect(x509): %s\n", backdata);
+            printf("SSL_BUG: scanssl(x509): %s\n", backdata);
             #endif
             X509_free(cert);
             SSL_shutdown(ssl); 
@@ -611,6 +657,7 @@ if(errno == EINPROGRESS){
             ERR_free_strings();
             free(senddata);
             free(url_data);
+            free(dns_data);
             free(backdata);
             exit(1);
             }
@@ -625,7 +672,7 @@ if(errno == EINPROGRESS){
 
          senddata = set_request(senddata, url_dom, url_pass);
          #ifdef SSL_BUG
-         printf("SSL_BUG: scan_ssl_connect(9): set_request*send-%s- %s\n", senddata, backdata);
+         printf("SSL_BUG: scanssl(9): set_request*send-%s- %s\n", senddata, backdata);
          #endif
 
          // 再度非同期通信の開始  SSL にした場合にFDはこれ使っていいのかな？？？
@@ -644,7 +691,7 @@ if(errno == EINPROGRESS){
             if(retval < 0){
                printf("URL=%s Port=%d %s %s\n", url_data, port, SOCK_15, URL_2);
                #ifdef SSL_BUG
-               printf("SSL_BUG: scan_ssl_connect(10): select error %s\n", backdata);
+               printf("SSL_BUG: scanssl(10): select error %s\n", backdata);
                #endif 
                // 非同期通信から同期通信
                fcntl(sk, F_SETFL, 0);
@@ -656,6 +703,7 @@ if(errno == EINPROGRESS){
                ERR_free_strings();
                free(senddata);
                free(url_data);
+               free(dns_data);
                free(backdata);
                exit(1);
                }
@@ -663,7 +711,7 @@ if(errno == EINPROGRESS){
             else if(retval == 0){
                printf("URL=%s Port=%d %s %s\n", url_data, port, SOCK_16, URL_3);
                #ifdef SSL_BUG
-               printf("SSL_BUG: scan_ssl_connect(11): select timed out %s\n", backdata); 
+               printf("SSL_BUG: scanssl(11): select timed out %s\n", backdata); 
                #endif 
                // 非同期通信から同期通信に
                fcntl(sk, F_SETFL, 0);
@@ -675,6 +723,7 @@ if(errno == EINPROGRESS){
                ERR_free_strings();
                free(senddata);
                free(url_data);
+               free(dns_data);
                free(backdata);
                exit(1);
                }
@@ -696,6 +745,7 @@ if(errno == EINPROGRESS){
                   ERR_free_strings();
                   free(senddata);
                   free(url_data);
+                  free(dns_data);
                   free(backdata);
                   exit(1);
                   }
@@ -709,7 +759,7 @@ if(errno == EINPROGRESS){
                   if(ret < 0){
                      printf("%s %s\n", URL_1, ssl_senddata);
                      #ifdef SSL_BUG
-                     printf("SSL_BUG: scan_ssl_connect(13): url check. not 200. ret<%d> %s\n", ret,backdata);
+                     printf("SSL_BUG: scanssl(13): url check. not 200. ret<%d> %s\n", ret,backdata);
                      #endif 
                      // 非同期通信から同期通信に
                      fcntl(sk, F_SETFL, 0);
@@ -721,13 +771,14 @@ if(errno == EINPROGRESS){
                      ERR_free_strings();
                      free(senddata);
                      free(url_data);
+                     free(dns_data);
                      free(backdata);
                      exit(1);
                      }
                   else{
                      backdata = safe_sprintf(backdata, BUF_MAX,"%s <%s>\n", URL_4, ssl_senddata);
                      #ifdef SSL_BUG
-                     printf("SSL_BUG: scan_ssl_connect(14): url check. all succesd. ret<%d> %s\n", ret, backdata);
+                     printf("SSL_BUG: scanssl(14): url check. all succesd. ret<%d> %s\n", ret, backdata);
                      #endif 
                      }
 
@@ -744,6 +795,7 @@ if(errno == EINPROGRESS){
                ERR_free_strings();
                free(senddata);
                free(url_data);
+               free(dns_data);
                free(backdata);
                exit(1);
                }
@@ -759,6 +811,7 @@ if(errno == EINPROGRESS){
          ERR_free_strings();
          free(senddata);
          free(url_data);
+         free(dns_data);
          free(backdata);
          exit(1);
          }
@@ -771,13 +824,14 @@ fcntl(sk, F_SETFL, 0);
 
 backdata=safe_sprintf(backdata,BUF_MAX, "URL=%s Port=%d %s", url_data, port, SOCK_14);
 #ifdef SSL_BUG
-printf("SSL_BUG: scan_ssl_connect(14): not connection err. %s\n", backdata); 
+printf("SSL_BUG: scanssl(14): not connection err. %s\n", backdata); 
 #endif 
 
 close(sk);
 
 free(senddata);
 free(url_data);
+free(dns_data);
 free(backdata);
 return 0;
 
