@@ -34,7 +34,7 @@ for(;;){
 
    // 一次リストファイルから二次リストファイルにコピー
    pthread_mutex_lock(&file4_mutex);
-   gd.fi.cronlist_filestat = stat_check(gd.fi.cronlist_filestat, gd.fi.cronlist_filename, IP_LEN, &bstat);
+   gd.fi.cronlist_filestat = stat_check(gd.fi.cronlist_filestat, gd.fi.cronlist_filename, &bstat);
    if(0 > bstat){
       #ifdef CRON_BUG
       printf("CRON_BUG: sitar_cron(): 編集があったので一次ファイルから二次ファイルにコピーします \n");
