@@ -1,25 +1,13 @@
-// sitar_scan.h
-// $Id: sitar_scan.h,v 1.2 2007/10/02 10:21:54 sendan Exp $
-// masashi shimakura
-
-#include<time.h>
-#include<pthread.h>
 
 #ifndef _SITAR_SCAN_H_
   #define _SITAR_SCAN_H_
 
-  #ifndef BUF_SLEN
-    #define BUF_SLEN 128
-  #endif
-  #ifndef BUF_LEN
-    #define BUF_LEN 512
-  #endif
-  #ifndef IP_LEN
-    #define IP_LEN 64
-  #endif
+  #include<time.h>
 
   #define BUF_URL 1024
 
+  #define DEFAULT_TIMEOUT 4
+
   /* RESOLV DEBUG */
 //  #define RESOLV_DEBUG
 
@@ -49,21 +37,6 @@
 
 
 
-typedef struct stred stred_t;
-
-struct stred{
-   char back_data[1024];
-   char name_data[1024];
-   int time;
-   int check;
-   pthread_t t_ret;
-   pthread_t t_chk;
-// pthread_mutex_t back_data_mutex;
-   };
-
-
-
-
   /* --- scan_icmp.c --- */
   char * scan_icmp(char *, char *, int, int *, int);
 
@@ -82,12 +55,17 @@ struct stred{
 
   /* --- scan_smtpport.c --- */
   char * scan_smtp_connect(int, char *, char *, int, int *);
-  char * resolvename(char *, char *, int, unsigned long *);
+  char * resolvename_th(char *, char *, int, unsigned long *);
+  char * resolvename_sk(char *, char *, int, unsigned long *, char *, int *);
   char * out_resolvename(char *, char *, int, unsigned long *);
   unsigned long resolve_name(char *name);
   time_t cert_time_get(char * data);
   char * th_resolv(char * name, char * back, int interval, int out);
 
+  /* --- scan_statport.c --- */
+  char * scan_stat_connect(int, char *, char *, char *, int, int, int *);
+
+
   /* --- scan_dhwport.c --- */
   char * scan_dhw_connect(char *, int, char *, char *, int, int *);
 
@@ -104,6 +82,9 @@ struct stred{
   char * check_recvdata(char *, char *, int *);
   int self_check_recvdata(char *, char *);
 
+   char * scan_dns_connect(int, char *, char *, char *, int, int *);
+
+
 #endif
 
 
