@@ -27,6 +27,9 @@ printf("th_miname_dump(): loop int =%d\n", gd.td.midint);
 
 for(;;){
    safe_pthread_mutex_lock(&name_mutex);
+   if(gd.td.midint < 60){
+      gd.td.midint = 60;
+      }
    fprintf(stderr,"th_miname_dump(): sleep time =%d, return  %d = miname_dump(void);\n",
      gd.td.midint, miname_dump(gd.fi.midump_filename_2));
    pthread_mutex_unlock(&name_mutex);
