@@ -68,6 +68,16 @@ if((FP = fopen(conf_filename, "r"))!=NULL){
                   case 24 : gd.db_select=safe_memcpy(gd.db_select, chC, LOGPATH_LEN);                       break;
                   case 25 : gd.on_bcc=safe_memcpy(gd.on_bcc, chC, LOGPATH_LEN);                             break;
                   case 26 : gd.cron_onoff = strtol(chC, (char **)NULL, 10);                                 break;
+                  case 27 :
+                            #ifdef SIGNATURE_MODE
+                            gd.sig.sig_filename = safe_memcpy(gd.sig.sig_filename, chC, LOGPATH_LEN);
+                            #endif
+                            break;
+                  case 28 :
+                            #ifdef SIGNATURE_MODE
+                            gd.sig.sig_interval = strtol(chC, (char **)NULL, 10);
+                            #endif
+                            break;
                   default : break;
                   }
 	       }
