@@ -189,6 +189,30 @@
 #define MAIL_PORT_28 "ƻ  : "
 #define MAIL_PORT_29 "Error   : "
 
+
+#define MAIL_ICMP_11 "-- ʲؤICMPѥåȤäƤޤ --"
+#define MAIL_ICMP_12 "      : "
+#define MAIL_ICMP_13 "ץȥ  : "
+#define MAIL_ICMP_14 "ۥ̾    : " 
+#define MAIL_ICMP_15 "ƻݡ  : "
+#define MAIL_ICMP_16 "Ԥ    : "
+#define MAIL_ICMP_17 "ƻ    : "
+#define MAIL_ICMP_18 "ƻ  : "
+#define MAIL_ICMP_19 "Error   : "
+
+
+#define MAIL_ICMP_21 "-- ʲؤICMPѥåȤäƤޤ --"
+#define MAIL_ICMP_22 "      : "
+#define MAIL_ICMP_23 "ץȥ  : "
+#define MAIL_ICMP_24 "ۥ̾    : " 
+#define MAIL_ICMP_25 "ƻݡ  : "
+#define MAIL_ICMP_26 "Ԥ    : "
+#define MAIL_ICMP_27 "ƻ    : "
+#define MAIL_ICMP_28 "ƻ  : "
+#define MAIL_ICMP_29 "Error   : "
+
+
+
 #define MAIL_COMMAND_11 "-- ʲΥޥɤ顼֤Ƥޤ --"
 #define MAIL_COMMAND_12 "       : "
 #define MAIL_COMMAND_13 "¹ԥޥ : "
