@@ -20,6 +20,8 @@ extern global_data_t gd;
 
 int malloc_set(void)
 {
+int count;
+
 /* selects data base */
 if((gd.db_select=(char*)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
 /* bcc seting use */
@@ -51,6 +53,17 @@ if((gd.md.ch_MailRcptTo=(char*)calloc(BUF_SLEN, sizeof(char)))==NULL){exit(1);}
 if((gd.md.ch_MailServ=(char*)calloc(BUF_SLEN, sizeof(char)))==NULL){exit(1);}
 if((gd.md.ch_MailCc=(char*)calloc(BUF_SLEN, sizeof(char)))==NULL){exit(1);}
 
+#ifdef SIGNATURE_MODE
+/* Mail Signature */
+if((gd.sig.sig_stat=(char*)calloc(BUF_SLEN, sizeof(char)))==NULL){exit(1);}
+if((gd.sig.sig_filename=(char*)calloc(BUF_SLEN, sizeof(char)))==NULL){exit(1);}
+
+if((gd.sig.sig_data=(char **)malloc(sizeof(char *) * (SIG_MAXLEN + 2)))==NULL){exit(1);}
+for(count = 0; count <= (SIG_MAXLEN + 2); count++){
+   if((gd.sig.sig_data[count]=(char *)calloc(IP_LEN, sizeof(char)))==NULL){exit(1);}
+   }
+#endif
+
 return 0;
 }
 
