@@ -34,18 +34,23 @@
 
 global_data_t gd;
 
-
+pthread_mutex_t sig_mutex;
 
 
 int main(int argc, char * argv[])
 {
 pthread_t t1;
+#ifdef SIGNATURE_MODE
+pthread_t t2;
+#endif
 long int fdcount;
 int tret;
 
 errno = 0;
 tret = 0;
 
+pthread_mutex_init(&sig_mutex, NULL);
+
 signal(SIGINT, signal_exit);
 signal(SIGKILL, signal_exit);
 signal(SIGQUIT, signal_exit);
@@ -101,11 +106,19 @@ if(-1 == (socket_bind(&gd.ms.my_addr, gd.ms.port, gd.ms.ip_addr, &gd.ms.ls))){
    exit(1);
    }
 
+
 /* client stop checker thread */
 if((tret = pthread_create( &t1, NULL, (void *)clockfile_check, NULL)) != 0){
-   fprintf(stderr,"zither.c: main(0): pthread_create %d\n", tret);
+   fprintf(stderr,"zither.c: main(0): t1 pthread_create %d\n", tret);
    }
 
+#ifdef SIGNATURE_MODE
+/* mail sign check */
+if((tret = pthread_create( &t2, NULL, (void *)mailsigfile_check, NULL)) != 0){
+   fprintf(stderr,"zither.c: main(1): t2 pthread_create %d\n", tret);
+   }
+#endif
+
 for(;;){
    for(fdcount = 0; fdcount < gd.ms.max_count; fdcount++){
       if(gd.ms.fdstat[fdcount] != 1){
@@ -139,6 +152,11 @@ for(;;){
       }
    }
 
+pthread_join( t1, NULL);
+#ifdef SIGNATURE_MODE
+pthread_join( t2, NULL);
+#endif
+
 /* --- It doesn't reach. ---*/
 close(gd.ms.ls);
 return 0;
