@@ -1,6 +1,3 @@
-// zither.h
-// $Id: zither.h,v 1.12 2007/11/14 04:42:08 sendan Exp $
-// masashi shimakura
 
 #ifndef _ZITHER_H_
   #define _ZITHER_H_
@@ -81,6 +78,7 @@
   //  #define MYSQL_DEBUG
   #endif
 
+  #define SIG_MAXLEN 10
 
 
   pthread_mutex_t err_mutex;
@@ -235,6 +233,15 @@
     struct {
        int uid;
        }exid; /* zither exit user id */
+    #ifdef SIGNATURE_MODE
+    struct {
+       char ** sig_data;  // x SIG_MAXLEN
+       char * sig_stat;
+       char * sig_filename;
+       int sig_interval;
+       int sig_len;
+       }sig; 
+    #endif
 
     };
 
